@@ -86,9 +86,9 @@ class MysqlHelper(RelationalDbHelper):
         :param param:
         :return:
         """
-        conn = self.pool.connection()
-        cursor = conn.cursor()
-        cursor.execute(sql, param)
+        with self.pool.connection() as conn:
+            with conn.cursor() as cursor:
+                cursor.execute(sql, param)
         return {"rowcount": cursor.rowcount}
 
     @echo_sql
@@ -99,9 +99,9 @@ class MysqlHelper(RelationalDbHelper):
         :param param:
         :return:
         """
-        conn = self.pool.connection()
-        cursor = conn.cursor()
-        cursor.executemany(sql, [tuple(item.values()) for item in param])
+        with self.pool.connection() as conn:
+            with conn.cursor() as cursor:
+                cursor.executemany(sql, [tuple(item.values()) for item in param])
         return {"rowcount": cursor.rowcount}
 
     @echo_sql
@@ -112,14 +112,14 @@ class MysqlHelper(RelationalDbHelper):
         :param param: 参数
         :return:
         """
-        conn = self.pool.connection()
-        cursor = conn.cursor()
-        if param:
-            cursor.execute(sql, param)
-        else:
-            cursor.execute(sql)
-        description = cursor.description
-        rs = cursor.fetchone()
+        with self.pool.connection() as conn:
+            with conn.cursor() as cursor:
+                if param:
+                    cursor.execute(sql, param)
+                else:
+                    cursor.execute(sql)
+                description = cursor.description
+                rs = cursor.fetchone()
         return BaseSqlHelper.dict_row(description, rs)
 
     @echo_sql
@@ -130,14 +130,14 @@ class MysqlHelper(RelationalDbHelper):
         :param param: 参数
         :return:
         """
-        conn = self.pool.connection()
-        cursor = conn.cursor()
-        if param:
-            cursor.execute(sql, param)
-        else:
-            cursor.execute(sql)
-        description = cursor.description
-        rs = cursor.fetchall()
+        with self.pool.connection() as conn:
+            with conn.cursor() as cursor:
+                if param:
+                    cursor.execute(sql, param)
+                else:
+                    cursor.execute(sql)
+                description = cursor.description
+                rs = cursor.fetchall()
         return BaseSqlHelper.dict_row(description, list(rs))
 
     def prepare_page_sql(self, condition_wrapper: ConditionWrapper, page_num: int, page_size: int):
