@@ -107,7 +107,8 @@ def Handler(url: str, desc=""):
     return wrapper
 
 
-def GetMapping(url: str = "", client_name: str = None, title: str = None, en_name: str = None, access: str = 1):
+def GetMapping(url: str = "", client_name: str = None, title: str = None, en_name: str = None, access: str = 1,
+               interface_desc: str = ""):
     """
     用于类名、处理方法、url 的元祖集合注册处理，暂时GetMapping与PostMapping实现保持一致，预留入口为后期扩展提供支持。
     :param client_name:
@@ -128,7 +129,7 @@ def GetMapping(url: str = "", client_name: str = None, title: str = None, en_nam
         func.__route_name__ = path
         func.__http_method__ = "get"
         try:
-            parser_swagger(func, title)
+            parser_swagger(func, (title if title else "") + interface_desc)
         except:
             pass
         return func
@@ -136,7 +137,8 @@ def GetMapping(url: str = "", client_name: str = None, title: str = None, en_nam
     return wrapper
 
 
-def PostMapping(url: str = "", client_name: str = None, title: str = None, en_name: str = None, access: str = 1):
+def PostMapping(url: str = "", client_name: str = None, title: str = None, en_name: str = None, access: str = 1,
+                interface_desc: str = ""):
     """
     用于类名、处理方法、url 的元祖集合注册处理，暂时GetMapping与PostMapping实现保持一致，预留入口为后期扩展提供支持。
     :param client_name:
@@ -157,7 +159,7 @@ def PostMapping(url: str = "", client_name: str = None, title: str = None, en_na
         func.__route_name__ = path
         func.__http_method__ = "post"
         try:
-            parser_swagger(func, title)
+            parser_swagger(func, (title if title else "") + interface_desc)
         except:
             pass
 
